==> charlatan_0.5.0.tar.gz: charlatan/R/jobs-provider-fa_IR.R <==
# modified from the python library faker:
# https://github.com/joke2k/faker/blob/master/faker/providers/job/fa_IR/__init__.py

job_formats_fa_ir <- c(
  "\u0647\u0646\u0631\f\u067e\u06cc\u0634\u0647",
  "\u0646\u0627\u062e\u062f\u0627",
  "\u0628\u062e\u0634\u062f\u0627\u0631",
  "\u062e\u06cc\u0627\u0637",
  "\u06af\u0644\u0647\f\u062f\u0627\u0631",
  "\u0628\u0627\u063a\f\u062f\u0627\u0631",
  "\u0645\u0624\u0630\u0646",
  "\u0633\u0627\u0631\u0628\u0627\u0646",
  "\u0622\u0634\u067e\u0632",
  "\u062f\u0646\u062f\u0627\u0646\f\u067e\u0632\u0634\u06a9",
  "\u0646\u062c\u0627\u0631",
  "\u0686\u0648\u067e\u0627\u0646",
  "\u062e\u0627\u0646\u0647\f\u062f\u0627\u0631",
  "\u0634\u0648\u0631\u0627",
  "\u0646\u0648\u06cc\u0633\u0646\u062f\u0647",
  "\u06af\u0627\u0631\u0633\u0648\u0646",
  "\u0627\u0633\u062a\u0627\u062f",
  "\u0641\u0631\u0648\u0634\u0646\u062f\u0647",
  "\u0634\u06cc\u0634\u0647\f\u0633\u0627\u0632",
  "\u0645\u062f\u06cc\u0631",
  "\u0646\u0642\u0627\u0634 \u0633\u0627\u062e\u062a\u0645\u0627\u0646",
  "\u0642\u0627\u06cc\u0642\u0631\u0627\u0646",
  "\u0631\u0641\u062a\u06af\u0631",
  "\u0648\u0632\u06cc\u0631",
  "\u062e\u0644\u0628\u0627\u0646",
  "\u0622\u0631\u0627\u06cc\u0634\u06af\u0631",
  "\u0631\u0648\u062d\u0627\u0646\u06cc",
  "\u0645\u062a\u062e\u0635\u0635",
  "\u0641\u0648\u062a\u0628\u0627\u0644\u06cc\u0633\u062a",
  "\u0642\u0635\u0627\u0628",
  "\u0633\u0627\u0639\u062a\f\u0633\u0627\u0632",
  "\u0628\u0642\u0627\u0644",
  "\u062a\u0644\u0641\u0646\f\u0686\u06cc",
  "\u062a\u0627\u062c\u0631",
  "\u0639\u06cc\u0646\u06a9\f\u0633\u0627\u0632",
  "\u062e\u0648\u0634\u0646\u0648\u06cc\u0633",
  "\u062c\u0646\u06af\u0644\u0628\u0627\u0646",
  "\u0645\u0639\u0644\u0645",
  "\u0645\u0647\u0646\u062f\u0633",
  "\u0631\u0627\u0646\u0646\u062f\u0647",
  "\u0622\u0630\u06cc\u0646 \u06af\u0631",
  "\u0646\u0638\u0627\u0645\u06cc",
  "\u0646\u0627\u0646\u0648\u0627",
  "\u0641\u0631\u0645\u0627\u0646\u062f\u0627\u0631",
  "\u062f\u0627\u0646\u0634\f\u0622\u0645\u0648\u0632",
  "\u062f\u0627\u0646\u0634\u062c\u0648",
  "\u062a\u0639\u0645\u06cc\u0631\u06a9\u0627\u0631",
  "\u06a9\u0634\u0627\u0648\u0631\u0632",
  "\u0647\u0646\u0631\u0645\u0646\u062f",
  "\u0645\u0639\u0627\u0648\u0646",
  "\u0628\u0627\u0646\u06a9\u062f\u0627\u0631",
  "\u0622\u0647\u0646\u06af\u0631",
  "\u0631\u0626\u06cc\u0633",
  "\u0633\u0631\u062a\u06cc\u067e",
  "\u0633\u0631\u0627\u06cc\u062f\u0627\u0631",
  "\u06a9\u0627\u0631\u0645\u0646\u062f",
  "\u0645\u0631\u0628\u06cc",
  "\u0633\u0631\u0647\u0646\u06af",
  "\u063a\u0648\u0627\u0635",
  "\u067e\u0632\u0634\u06a9",
  "\u062f\u0631\u0628\u0627\u0646",
  "\u0622\u062a\u0634\f\u0646\u0634\u0627\u0646",
  "\u0645\u0627\u0647\u06cc\f\u06af\u06cc\u0631",
  "\u0645\u06cc\u0648\u0647\f\u0641\u0631\u0648\u0634",
  "\u0646\u06af\u0647\u0628\u0627\u0646",
  "\u067e\u0627\u0633\u062f\u0627\u0631",
  "\u0642\u0627\u0636\u06cc",
  "\u0648\u06a9\u06cc\u0644",
  "\u06a9\u0627\u0631\u06af\u0631",
  "\u0634\u0647\u0631\u062f\u0627\u0631",
  "\u0645\u0639\u062f\u0646\f\u0686\u06cc",
  "\u067e\u0631\u0633\u062a\u0627\u0631",
  "\u0627\u0641\u0633\u0631",
  "\u0639\u06a9\u0627\u0633",
  "\u0644\u0648\u0644\u0647\f\u06a9\u0634",
  "\u0628\u0627\u0632\u06cc\u06af\u0631",
  "\u0628\u0627\u0631\u0628\u0631",
  "\u0631\u0626\u06cc\u0633\f\u062c\u0645\u0647\u0648\u0631",
  "\u0646\u062e\u0633\u062a\f\u0648\u0632\u06cc\u0631",
  "\u0631\u0648\u0627\u0646\u0634\u0646\u0627\u0633",
  "\u062e\u0628\u0631\f\u0646\u06af\u0627\u0631",
  "\u0628\u0627\u0632\u0646\u0634\u0633\u062a\u0647",
  "\u0645\u062c\u0633\u0645\u0647\f\u0633\u0627\u0632",
  "\u06af\u0631\u0648\u0647\u0628\u0627\u0646",
  "\u0645\u063a\u0627\u0632\u0647\f\u062f\u0627\u0631",
  "\u062e\u0648\u0627\u0646\u0646\u062f\u0647",
  "\u0633\u0631\u0628\u0627\u0632",
  "\u0633\u062e\u0646\f\u0631\u0627\u0646",
  "\u062c\u0631\u0627\u062d",
  "\u0633\u0641\u0627\u0644\f\u06af\u0631",
  "\u062c\u0647\u0627\u0646\u06af\u0631\u062f",
  "\u062c\u0648\u0634\u06a9\u0627\u0631",
  "\u0686\u0634\u0645\f\u067e\u0632\u0634\u06a9",
  "\u06af\u0632\u0627\u0631\u0634\f\u06af\u0631",
  "\u062e\u0637\u0627\u0637"
)

==> charlatan_0.6.2.tar.gz: charlatan/R/jobs-provider-fa_IR.R <==
# modified from the python library faker:
# https://github.com/joke2k/faker/blob/master/faker/providers/job/fa_IR/__init__.py

job_formats_fa_ir <- c(
  "\u0647\u0646\u0631\f\u067e\u06cc\u0634\u0647",
  "\u0646\u0627\u062e\u062f\u0627",
  "\u0628\u062e\u0634\u062f\u0627\u0631",
  "\u062e\u06cc\u0627\u0637",
  "\u06af\u0644\u0647\f\u062f\u0627\u0631",
  "\u0628\u0627\u063a\f\u062f\u0627\u0631",
  "\u0645\u0624\u0630\u0646",
  "\u0633\u0627\u0631\u0628\u0627\u0646",
  "\u0622\u0634\u067e\u0632",
  "\u062f\u0646\u062f\u0627\u0646\f\u067e\u0632\u0634\u06a9",
  "\u0646\u062c\u0627\u0631",
  "\u0686\u0648\u067e\u0627\u0646",
  "\u062e\u0627\u0646\u0647\f\u062f\u0627\u0631",
  "\u0634\u0648\u0631\u0627",
  "\u0646\u0648\u06cc\u0633\u0646\u062f\u0647",
  "\u06af\u0627\u0631\u0633\u0648\u0646",
  "\u0627\u0633\u062a\u0627\u062f",
  "\u0641\u0631\u0648\u0634\u0646\u062f\u0647",
  "\u0634\u06cc\u0634\u0647\f\u0633\u0627\u0632",
  "\u0645\u062f\u06cc\u0631",
  "\u0646\u0642\u0627\u0634 \u0633\u0627\u062e\u062a\u0645\u0627\u0646",
  "\u0642\u0627\u06cc\u0642\u0631\u0627\u0646",
  "\u0631\u0641\u062a\u06af\u0631",
  "\u0648\u0632\u06cc\u0631",
  "\u062e\u0644\u0628\u0627\u0646",
  "\u0622\u0631\u0627\u06cc\u0634\u06af\u0631",
  "\u0631\u0648\u062d\u0627\u0646\u06cc",
  "\u0645\u062a\u062e\u0635\u0635",
  "\u0641\u0648\u062a\u0628\u0627\u0644\u06cc\u0633\u062a",
  "\u0642\u0635\u0627\u0628",
  "\u0633\u0627\u0639\u062a\f\u0633\u0627\u0632",
  "\u0628\u0642\u0627\u0644",
  "\u062a\u0644\u0641\u0646\f\u0686\u06cc",
  "\u062a\u0627\u062c\u0631",
  "\u0639\u06cc\u0646\u06a9\f\u0633\u0627\u0632",
  "\u062e\u0648\u0634\u0646\u0648\u06cc\u0633",
  "\u062c\u0646\u06af\u0644\u0628\u0627\u0646",
  "\u0645\u0639\u0644\u0645",
  "\u0645\u0647\u0646\u062f\u0633",
  "\u0631\u0627\u0646\u0646\u062f\u0647",
  "\u0622\u0630\u06cc\u0646 \u06af\u0631",
  "\u0646\u0638\u0627\u0645\u06cc",
  "\u0646\u0627\u0646\u0648\u0627",
  "\u0641\u0631\u0645\u0627\u0646\u062f\u0627\u0631",
  "\u062f\u0627\u0646\u0634\f\u0622\u0645\u0648\u0632",
  "\u062f\u0627\u0646\u0634\u062c\u0648",
  "\u062a\u0639\u0645\u06cc\u0631\u06a9\u0627\u0631",
  "\u06a9\u0634\u0627\u0648\u0631\u0632",
  "\u0647\u0646\u0631\u0645\u0646\u062f",
  "\u0645\u0639\u0627\u0648\u0646",
  "\u0628\u0627\u0646\u06a9\u062f\u0627\u0631",
  "\u0622\u0647\u0646\u06af\u0631",
  "\u0631\u0626\u06cc\u0633",
  "\u0633\u0631\u062a\u06cc\u067e",
  "\u0633\u0631\u0627\u06cc\u062f\u0627\u0631",
  "\u06a9\u0627\u0631\u0645\u0646\u062f",
  "\u0645\u0631\u0628\u06cc",
  "\u0633\u0631\u0647\u0646\u06af",
  "\u063a\u0648\u0627\u0635",
  "\u067e\u0632\u0634\u06a9",
  "\u062f\u0631\u0628\u0627\u0646",
  "\u0622\u062a\u0634\f\u0646\u0634\u0627\u0646",
  "\u0645\u0627\u0647\u06cc\f\u06af\u06cc\u0631",
  "\u0645\u06cc\u0648\u0647\f\u0641\u0631\u0648\u0634",
  "\u0646\u06af\u0647\u0628\u0627\u0646",
  "\u067e\u0627\u0633\u062f\u0627\u0631",
  "\u0642\u0627\u0636\u06cc",
  "\u0648\u06a9\u06cc\u0644",
  "\u06a9\u0627\u0631\u06af\u0631",
  "\u0634\u0647\u0631\u062f\u0627\u0631",
  "\u0645\u0639\u062f\u0646\f\u0686\u06cc",
  "\u067e\u0631\u0633\u062a\u0627\u0631",
  "\u0627\u0641\u0633\u0631",
  "\u0639\u06a9\u0627\u0633",
  "\u0644\u0648\u0644\u0647\f\u06a9\u0634",
  "\u0628\u0627\u0632\u06cc\u06af\u0631",
  "\u0628\u0627\u0631\u0628\u0631",
  "\u0631\u0626\u06cc\u0633\f\u062c\u0645\u0647\u0648\u0631",
  "\u0646\u062e\u0633\u062a\f\u0648\u0632\u06cc\u0631",
  "\u0631\u0648\u0627\u0646\u0634\u0646\u0627\u0633",
  "\u062e\u0628\u0631\f\u0646\u06af\u0627\u0631",
  "\u0628\u0627\u0632\u0646\u0634\u0633\u062a\u0647",
  "\u0645\u062c\u0633\u0645\u0647\f\u0633\u0627\u0632",
  "\u06af\u0631\u0648\u0647\u0628\u0627\u0646",
  "\u0645\u063a\u0627\u0632\u0647\f\u062f\u0627\u0631",
  "\u062e\u0648\u0627\u0646\u0646\u062f\u0647",
  "\u0633\u0631\u0628\u0627\u0632",
  "\u0633\u062e\u0646\f\u0631\u0627\u0646",
  "\u062c\u0631\u0627\u062d",
  "\u0633\u0641\u0627\u0644\f\u06af\u0631",
  "\u062c\u0647\u0627\u0646\u06af\u0631\u062f",
  "\u062c\u0648\u0634\u06a9\u0627\u0631",
  "\u0686\u0634\u0645\f\u067e\u0632\u0634\u06a9",
  "\u06af\u0632\u0627\u0631\u0634\f\u06af\u0631",
  "\u062e\u0637\u0627\u0637"
)

#' Job provider for Iran (Persian)
#'
#' @inherit JobProvider description details return
#' @family fa
#' @family IR
#' @export
#' @examples
#' x <- JobProvider_fa_IR$new()
#' x$render()
JobProvider_fa_IR <- R6::R6Class(
  inherit = JobProvider,
  "JobProvider_fa_IR",
  private = list(
    locale_ = "fa_IR",
    formats = job_formats_fa_ir
  )
)
